/* DO NOT EDIT! GENERATED AUTOMATICALLY! */

/* Virtual function table layout of superclass.  */
#include "ostream.vt.h"

/* Virtual function table layout of iconv_ostream class.  */
      const char * (*get_from_encoding) (THIS_ARG);
   const char * (*get_to_encoding) (THIS_ARG);
   ostream_t    (*get_destination) (THIS_ARG);
